@@ -1,9 +1,9 @@
-from aqueue.display import Display
+from aqueue.display import SetDescFn
 from aqueue.processing import async_run_queue, run_queue
 from aqueue.queue import EnqueueFn, Item, QueueTypeName
 
 __all__ = (
-    "Display",
+    "SetDescFn",
     "EnqueueFn",
     "Item",
     "QueueTypeName",
